@@ -33,6 +33,10 @@ module Async
 			
 			wrap_blocking_method :sendmsg, :sendmsg_nonblock
 			wrap_blocking_method :send, :sendmsg_nonblock, invert: false
+			
+			def type
+				self.local_address.socktype
+			end
 		end
 		
 		module ServerSocket
@@ -42,8 +46,8 @@ module Async
 				wrapper = Socket.new(peer, self.reactor)
 				
 				if block_given?
-					task.async do
-						task.annotate "incoming connection #{address}"
+					task.async do |task|
+						task.annotate "incoming connection #{address.inspect}"
 						
 						begin
 							yield wrapper, address
